# Aladdin

## Application Information

### 💡 What is Aladdin?

Aladdin (Alaya AI addin) is an operational addin developed by ‌DataCanvas‌ based on ‌Serverless architecture‌, specifically designed for users managing VKS on the ‌ALaya NeW platform. With this addin, users can remotely connect to VKS for efficient development, debugging, and model training. Supported by Aladdin, users can complete model training and optimization with the most efficient computing power configurations, thereby significantly improving resource utilization and development efficiency‌.

### 🌟 Advantages of Aladdin

🍓**Development Experience Free from Operation and Maintenance**

The Aladdin enables direct connectivity to VKS, seamlessly integrating local development environments with cloud computing resources. By eliminating the complexities of underlying Operation and Maintenance (O&M), it empowers developers to focus on model iteration and algorithmic innovation.

🍓**Zero-Idle-Resource Architecture**

Based on the Serverless intelligent scaling mechanism, computing resources can dynamically scale at the millisecond level, with instances released immediately upon task completion. Additionally, the service is billed according to the actual compute duration, thereby eliminating idle costs.

🍓**Cost-effective computing resource utilization**

Aladdin dynamically allocates GPU/NPU heterogeneous computing resources on demand, enabling large model training tasks to resume seamlessly from checkpoints after interruptions. This ensures every unit of computing power directly contributes to achieving business objectives.


### 🚀 Getting Start

1. **Activate VKS**: Complete login and activate VKS on the Alaya NeW platform. For registration and login, refer to：[Account registration and user management](https://docs.alayanew.com/docs/documents/quickStart/createUser/); For VKS activation, refer to：[VKS activation and management](https://docs.alayanew.com/docs/documents/quickStart/OpenElasticContainerCluster)

2. **Activate Image Repository**：Activate Image Repository on the Alaya NeW platform. For Image Repository activation,refer to：[Storage activation and management](https://docs.alayanew.com/docs/documents/quickStart/storageManagement)

3. **Install Aladdin and Log In**：After installing Aladdin from the Extensions, click 'Log In' in the Aladdin toolbar. Enter your username and password on the pop-up login page to log in, and then select AI Data Center.

   ![login](https://alaya-aladding-assets-prod.oss-cn-beijing.aliyuncs.com/aladdin/1.6/login.gif)

4. **Create Workshop**：After configuring the username and password for the image registry (Environments), click 'Add CodeSpace' on the right side of the Workshop under the Aladdin toolbar and fill in the configuration details. You can select resources under VKS and images from the image registry (Environments) as needed, with support for mounting storage。After clicking **Submit**, remote workspace will be launched.

   **configuring the username and password for the image registry (Environments)**

      ![harbor](https://alaya-aladding-assets-prod.oss-cn-beijing.aliyuncs.com/aladdin/1.6/harbor.gif)

   **Create and launch the Workshop**

      ![workshop](https://alaya-aladding-assets-prod.oss-cn-beijing.aliyuncs.com/aladdin/1.6/workshop.gif)
   

5. **Coding and Running**：In a remote workspace, you can utilize VSCode for model development, debugging, and training. By installing Aladdin to connect remotely to VKS, you can leverage VKS resources for code running and debugging, with files and data stored on shared storage.
   
      ![session](https://alaya-aladding-assets-prod.oss-cn-beijing.aliyuncs.com/aladdin/1.6/session.gif)



### 📖 Key Features Overview：

**workshop**
Workshop serves as the user's workspace (data is stored on shared storage). Users can customize the image, compute resources, environment variables, and mount storage volumes as needed to create their workspace. Within each workspace, users can develop, debug, and train models using the remote VSCode environment, and utilize VKS resources to debug and execute programs.

**Development with VKS Resources**
‌Within the Workshop workspace, you can utilize VKS resources to execute programs: Python programs support GPU Run and GPU Debug, while Shell scripts support Run Shell. Each execution allows real-time configuration of required images and resources, with automatic resource release upon success or failure, ensuring model training and optimization are completed with the most optimized computational configuration.
   * GPU Debug: Remotely launch GPU resources to perform remote debugging; GPU resources will be automatically released upon successful/failed debugging or manual disconnection from the remote debug session.
   * GPU Run: Remotely launch GPU resources to run Python programs; the GPU resources will be automatically released upon successful or failed execution.
   * Run Shell：Remotely launch GPU resources to execute a shell script, the GPU resources will be automatically released upon successful or failed execution.

**Session Management**
GPU RUN, RUN shell, and GPU DEBUG each generate a session. Click the GPU Debug plugin icon in the Workshop to view the session list, which supports accessing session logs and Terminal.

**Image saving**
If development environments or dependency packages are installed in the Workshop, the Workshop can be saved as an image. Right-click the target Workshop in the Workshop list, select ‌Save Environment‌, and enter an image name to complete the save. Once the image is successfully saved, you can optionally replace the Workshop's image with the newly saved one.

### IDE Version Description
- Aladdin supports VS Code version 1.93 and above.
- Aladdin supports Cursor based on VS Code 1.93 or higher.